; List
; A highlighting bordered paragraph.
;
; Functions:
; 1. guiDrawList
; 2. guiShowList
; 3. guiHideList
; 4. guiSetList				Set the currently selected list element
;
; Comments:
;  LI_NoBuffer is used internally for "save-behind" when using droplists. Never
;   use it in a form, as all normal form elements are drawn to the buffer, and
;   some draw routines automatically copy the buffer (ex. checkbox/bitmap).
;  There cannot be 0 items in the list.
;  The list is fitted to the number of elements, so that proper spacing is
;   maintained above and below. However, no checks are made to see if it will fit
;   on the screen. Horizontal size is the responsibility of the calling program.
;  When specifying a list element, 0 is the first, 1 is the second, and so on.
;

LI_BigFont		equ	0
LI_Inverse		equ	1
LI_Centered		equ	2
LI_NoBorder		equ	3
LI_Showing		equ	4
LI_NoBuffer		equ	5

guiShowList:
 inc hl
 inc hl
 inc hl
 set LI_Showing,(hl)
 dec hl
 dec hl
 dec hl
 jr guiDrawList
guiHideList:
 inc hl
 inc hl
 inc hl
 res LI_Showing,(hl)
 dec hl
 dec hl
 dec hl
guiDrawList:
 res textwrite,(iy+textflags)
 ld e,(hl)
 inc hl
 ld d,(hl)
 inc hl
 ld c,(hl)
 inc hl
 push hl
 pop ix
 ld a,(ix+2)
 add a,a
 ld b,a
 add a,a
 add a,b
 bit LI_BigFont,(hl)
 jr z,guiDrawListSmall
 add a,b
guiDrawListSmall:
 bit LI_NoBorder,(hl)
 jr nz,guiDrawListNoBorderOffset
 add a,2
guiDrawListNoBorderOffset:
 ld h,a
 ld l,c
 push de
 add hl,de
 ex de,hl
 pop hl
 res plotLoc,(iy+plotFlags)
 bit LI_NoBuffer,(ix)
 jr z,guiDrawListBuffer
 set plotLoc,(iy+plotFlags)
guiDrawListBuffer:
 bit LI_Showing,(ix)
 jp z,guiEraseList
 push de
 push hl
 push de
 push ix
 B_CALL _clearrect
 pop ix
 pop de
 pop hl
 bit LI_NoBorder,(ix)
 jr nz,guiDrawListNoBorder
 push hl
 push de
 push ix
 B_CALL _drawrectborder
 pop ix
 pop de
 pop hl
guiDrawListNoBorder:
 res textInverse,(iy+textflags)
 bit LI_Inverse,(ix)
 jr z,guiDrawListNotInverse
 push hl
 push de
 push ix
 B_CALL _invertrect
 pop ix
 pop de
 pop hl
 set textinverse,(iy+textflags)
guiDrawListNotInverse:
 inc l
 bit LI_NoBorder,(ix)
 jr nz,guiDrawListNoBOffset
 inc h
 inc l
guiDrawListNoBOffset:
 res fracDrawLFont,(iy+fontFlags)
 bit LI_BigFont,(ix)
 jr z,guiDrawListNoVOffset
 inc h
 set fracDrawLFont,(iy+fontFlags)
guiDrawListNoVOffset:
 ex de,hl
 bit LI_Centered,(ix)
 jr z,guiDrawListNotCentered
 ld a,(ix-1)
 sra a
 inc a
 add a,(ix-3)
 ld e,a
guiDrawListNotCentered:
 push ix
 pop hl
 inc hl
 push hl
 inc hl
 bit LI_NoBuffer,(ix)
 jr nz,guiDrawListTextNotBuffered
 bit LI_Centered,(ix)
 push af
 call nz,multilinetextC2
 pop af
 call z,multilinetextL2
 jr guiDrawListDoInvert
guiDrawListTextNotBuffered:
 bit LI_Centered,(ix)
 push af
 call nz,multilinetextC
 pop af
 call z,multilinetextL
guiDrawListDoInvert:
 pop hl
 ld a,(hl)
 add a,a
 ld b,a
 add a,a
 add a,b
 bit LI_BigFont,(ix)
 jr z,guiDrawListSmall2
 add a,b
guiDrawListSmall2:
 inc a
 add a,(ix-2)
 ld h,a
 ld l,(ix-3)
 pop de
 ld a,6
 bit LI_BigFont,(ix)
 jr z,guiDrawListSmall3
 ld a,8
guiDrawListSmall3:
 add a,h
 ld d,a
 bit LI_NoBorder,(ix)
 jr nz,guiDrawListNoShrink
 dec e
 inc l
 jr guiDrawListWasShrunk
guiDrawListNoShrink:
 dec h
 dec d
guiDrawListWasShrunk:
 B_CALL _invertrect
 res textinverse,(iy+textflags)
 res fracDrawLFont,(iy+fontflags)
 res plotloc,(iy+plotflags)
 ret

guiEraseList:
 bit LI_NoBuffer,(ix)
 jr z,guiEraseListOnBuffer
 B_CALL _grbufcpy
 ret
guiEraseListOnBuffer:
 bit LI_Inverse,(ix)
 jr nz,guiEraseListFill
 B_CALL _clearrect
 ret
guiEraseListFill:
 B_CALL _fillrect
 ret

guiSetList:
 push hl
 pop ix
 bit LI_Showing,(ix+3)
 jr nz,guiSetListNotHidden
 ld de,4
 add hl,de
 ld (hl),a
 ret
guiSetListNotHidden:
 push af
 push hl
 push ix
 call guiSetListInvertCurrent
 pop ix
 pop hl
 pop af
 ld de,4
 add hl,de
 ld (hl),a
 sbc hl,de
guiSetListInvertCurrent:
 inc hl
 inc hl
 inc hl
 push hl
 pop ix
 res plotLoc,(iy+plotFlags)
 bit LI_NoBuffer,(ix)
 jr z,guiSetListBuffer
 set plotLoc,(iy+plotFlags)
guiSetListBuffer:
 inc hl
 ld a,(hl)
 add a,a
 ld b,a
 add a,a
 add a,b
 bit LI_BigFont,(ix)
 jr z,guiSetListSmall
 add a,b
guiSetListSmall:
 inc a
 add a,(ix-2)
 ld h,a
 ld a,(ix-3)
 ld l,a
 add a,(ix-1)
 ld e,a
 ld a,6
 bit LI_BigFont,(ix)
 jr z,guiSetListSmall2
 ld a,8
guiSetListSmall2:
 add a,h
 ld d,a
 bit LI_NoBorder,(ix)
 jr nz,guiSetListNoShrink
 dec e
 inc l
 jr guiSetListWasShrunk
guiSetListNoShrink:
 dec h
 dec d
guiSetListWasShrunk:
 B_CALL _invertrect
 ret

guiHandleList:
 push hl
 pop ix
 push de
 ld de,pencol
 ldi
 ldi
 pop de
 ld b,(hl)
 inc hl
 bit LI_Showing,(hl)
 ret z
 inc hl
 inc hl
 ld a,(hl)
 ld l,b
 add a,a
 ld b,a
 add a,a
 add a,b
 bit LI_BigFont,(ix+3)
 jr z,guiHandleListSmall
 add a,b
guiHandleListSmall:
 bit LI_NoBorder,(ix+3)
 jr nz,guiHandleListNoBorderOffset
 add a,2
guiHandleListNoBorderOffset:
 ld h,a
 ld bc,(pencol)
 add hl,bc
 call IsInRectangle
 ret c
 ld a,d
 sub b
 jr z,guiHandleListNoDec
 dec a
guiHandleListNoDec:
 ld l,a
 ld a,6
 bit LI_BigFont,(ix+3)
 jr z,guiHandleListSmall2
 ld a,8
guiHandleListSmall2:
 ld h,0
 B_CALL _divhlbya
 ld a,l
 cp (ix+5)
 jr nz,guiHandleListOK
 dec a
guiHandleListOK:
 push ix
 pop hl
 push hl
 push af
 call guiSetList
 pop af
 pop ix
 bit LI_NoBuffer,(ix+3)
 jp z,guiHandleClickFinished
 or a		; reset carry
 ret		; Return control to dropbox so as to let it update pointers