; Window
; A box with a centered title.
; Inputs: hl -> Window structure
;
; Window Structure:
; .db top			; Top pixel row
; .db left			; Left pixel column
; .db bottom		; Bottom pixel row
; .db right			; Right pixel column
; .db "Title",0	; Title
;
; Comments:
;  Writes to buffer and screen.
;

guiWindow:
 ld a,(hl)
 inc hl
 ld b,(hl)
 inc hl
 ld d,(hl)
 inc hl
 ld e,(hl)
 inc hl
 push hl
 ld h,a
 ld l,b
 res plotloc,(iy+plotflags)
 push hl
 push de
 B_CALL _drawrectborderc
 pop de
 pop hl
 ld a,l
 add a,e		;will not carry
 rra			;average
 ld c,a
 ld b,h
 ld (pencol),bc
 ld a,7
 add a,h
 ld d,a
 push bc
 B_CALL _fillrect
 pop bc
 pop hl
 ld a,(flags+sgrflags)
 set textinverse,(iy+textflags)
 res fracDrawLFont,(iy+fontflags)
 push af
 push af
 push bc
 push hl
 call centertext
 pop hl
 pop bc
 pop af
 ld (pencol),bc
 xor 1<<textwrite
 ld (flags+sgrflags),a
 call centertext
 pop af
 ld (flags+sgrflags),a
 res textinverse,(iy+textflags)
 ret


; WindowEX
; A box with a title, and extra options.
; Inputs: hl -> WindowEX structure
;
; WindowEX Structure:
; .db flags
; .db top
; .db left
; .db bottom
; .db right
; .db titleheight
; .db num_titles
; .db "Title 1",0
; .db "Title 2",0
;
; Flags:
;  Bit 0: WI_Buffer
;  Bit 1: WI_CenterTitle
;  Bit 2: WI_BigTitle
;
; Comments:
;

WI_Buffer			equ	0
WI_CenterTitle		equ	1
WI_BigTitle			equ	2

guiWindowEX:
 push hl
 pop ix
 inc hl
 ld a,(hl)
 inc hl
 ld b,(hl)
 inc hl
 ld d,(hl)
 inc hl
 ld e,(hl)
 inc hl
 inc hl
 push hl
 ld h,a
 ld l,b
 res plotloc,(iy+plotflags)
 bit WI_Buffer,(ix)
 jr nz,guiWindowEXBuffered
 set plotloc,(iy+plotflags)
guiWindowEXBuffered:
 push hl
 push de
 push ix
 B_CALL _drawrectborderc
 pop ix
 pop de
 pop hl
 bit WI_CenterTitle,(ix)
 jr nz,guiWindowEXCenter
 inc l
 ld (pencol),hl
 ld b,h
 ld c,l
 jr guiWindowEXLeft
guiWindowEXCenter:
 ld a,l
 add a,e
 rra
 ld c,a
 ld b,h
 ld (pencol),bc
guiWindowEXLeft:
 ld a,(ix+5)
 add a,h
 ld d,a
 push bc
 B_CALL _fillrect
 pop bc
 ld d,b
 ld e,c
 pop hl
 ld a,(flags+sgrflags)
 push af
 set textinverse,(iy+textflags)
 res fracDrawLFont,(iy+fontFlags)
 bit WI_BigTitle,(ix)
 jr z,guiWindowEXSmall
 set fracDrawLFont,(iy+fontFlags)
 inc d
guiWindowEXSmall:
 bit WI_Buffer,(ix)
 jr z,guiWindowEXNoBufferText
 set textwrite,(iy+sgrflags)
 push de
 push hl
 bit WI_CenterTitle,(ix)
 push af
 call nz,multilinetextC
 pop af
 call z,multilinetextL
 pop hl
 pop de
guiWindowEXNoBufferText:
 res textwrite,(iy+sgrflags)
 bit WI_CenterTitle,(ix)
 push af
 call nz,multilinetextC
 pop af
 call z,multilinetextL
 pop af
 ld (flags+sgrflags),a
 res textinverse,(iy+textflags)
 res fracDrawLFont,(iy+fontFlags)
 ret
